@@ -13,6 +13,7 @@ from .util import cache, stdout_encode, debug
 
 
 API_URL = 'http://{lang}{sub_wikia}.wikia.com/api/v1/{action}'
+# URL used when browsing the wikia proper
 STANDARD_URL = 'http://{lang}{sub_wikia}.wikia.com/wiki/{page}'
 LANG = ""
 RATE_LIMIT = False
@@ -98,17 +99,11 @@ def search(query, sub_wikia, results=10):
 
   raw_results = _wiki_request(search_params)
 
-  if 'error' in raw_results:
-    if raw_results['error']['info'] in ('HTTP request timed out.', 'Pool queue is full'):
-      raise HTTPTimeoutError(query)
-    else:
-      raise WikiaException(raw_results['error']['info'])
-
   try:
       search_results = (d['title'] for d in raw_results['items'])
   except KeyError as e:
       raise WikiaError("Could not locate page \"{}\" in subwikia \"{}\"".format(query,
-                                                                            sub_wikia))     
+                                                                            sub_wikia))
   return list(search_results)
 
 
@@ -124,9 +119,6 @@ def random(pages=1):
   '''
   #http://en.wikia.org/w/api.php?action=query&list=random&rnlimit=5000&format=
   query_params = {
-    'list': 'random',
-    'rnnamespace': 0,
-    'rnlimit': pages,
     'lang': LANG
   }
 
@@ -163,9 +155,8 @@ def summary(title, sub_wikia, chars=500, redirect=True):
     'action': 'Articles/Details?/',
     'sub_wikia': sub_wikia,
     'titles': title,
-    'query': title,
-    'abstract': chars,
     'ids': pageid,
+    'abstract': chars,
     'lang': LANG
   }
 
@@ -243,12 +234,8 @@ class WikiaPage(object):
     Does not need to be called manually, should be called automatically during __init__.
     '''
     query_params = {
-      'sub_wikia': self.sub_wikia,
       'action': 'Articles/Details?/',
-      'prop': 'info|pageprops',
-      'inprop': 'url',
-      'ppprop': 'disambiguation',
-      'redirects': '',
+      'sub_wikia': self.sub_wikia,
       'lang': LANG,
     }
     if not getattr(self, 'pageid', None):
@@ -256,7 +243,12 @@ class WikiaPage(object):
     else:
       query_params['ids'] = self.pageid
 
-    request = _wiki_request(query_params)
+    try:
+        request = _wiki_request(query_params)
+    except IndexError:
+        raise WikiaError("Could not find page \"{}\""
+                         "of the sub-wikia {}".format(self.title or self.pageid,
+                                                      self.sub_wikia))
     query = list(request['items'].values())[0]
     pageid = query['id']
     page = query
@@ -296,10 +288,6 @@ class WikiaPage(object):
     # then the page must be a disambiguation page
     elif 'pageprops' in page:
       query_params = {
-        'prop': 'revisions',
-        'rvprop': 'content',
-        'rvparse': '',
-        'rvlimit': 1,
         'lang': LANG,
       }
       if hasattr(self, 'pageid'):
@@ -367,41 +355,35 @@ class WikiaPage(object):
     '''
 
     if not getattr(self, '_html', False):
-      query_params = {
-        'prop': 'revisions',
-        'rvprop': 'content',
-        'rvlimit': 1,
-        'rvparse': '',
-        'titles': self.title,
-        'lang': LANG,
-      }
-
-      request = _wiki_request(query_params)
-      self._html = request['query']['pages'][self.pageid]['revisions'][0]['*']
+      request = requests.get(self.url)
+      self._html = request.text
 
     return self._html
 
   @property
   def content(self):
     '''
-    Plain text content of the page, excluding images, tables, and other data.
+    Plain text content of each section of the page, excluding images, tables,
+    and other data.
     '''
-
     if not getattr(self, '_content', False):
+      # First get the plaintext summary
       query_params = {
-        'prop': 'extracts|revisions',
-        'explaintext': '',
-        'rvprop': 'ids',
+        'action': "Articles/AsSimpleJson?/",
+        'id': self.pageid,
+        'ids': self.pageid, # Because for some reason the API uses both "id" and "ids"
+        'sub_wikia': self.sub_wikia,
         'lang': LANG
       }
-      if not getattr(self, 'title', None) is None:
-         query_params['titles'] = self.title
-      else:
-         query_params['pageids'] = self.pageid
+
       request = _wiki_request(query_params)
-      self._content     = request['query']['pages'][self.pageid]['extract']
-      self._revision_id = request['query']['pages'][self.pageid]['revisions'][0]['revid']
-      self._parent_id   = request['query']['pages'][self.pageid]['revisions'][0]['parentid']
+      self._content = "\n".join(segment['text'] for section in request['sections']
+                                                for segment in section['content']
+                                                if segment['type'] == "paragraph")
+      # Then get the revision id
+      query_params['action'] = "Articles/Details?/"
+      request = _wiki_request(query_params)
+      self._revision_id = request['items'][str(self.pageid)]['revision']['id']
 
     return self._content
 
@@ -423,19 +405,6 @@ class WikiaPage(object):
 
     return self._revision_id
 
-  @property
-  def parent_id(self):
-    '''
-    Revision ID of the parent version of the current revision of this
-    page. See ``revision_id`` for more information.
-    '''
-
-    if not getattr(self, '_parentid', False):
-      # fetch the content (side effect is loading the revid)
-      self.content
-
-    return self._parent_id
-
   @property
   def summary(self):
     '''
@@ -444,13 +413,10 @@ class WikiaPage(object):
 
     if not getattr(self, '_summary', False):
       query_params = {
-        'query': self.title,
         'action': 'Articles/Details?/',
-        'prop': 'extracts',
-        'explaintext': '',
-        'exintro': '',
-        'lang': LANG,
+        'query': self.title,
         'sub_wikia': self.sub_wikia,
+        'lang': LANG,
       }
       if not getattr(self, 'title', None) is None:
          query_params['titles'] = self.title
@@ -469,81 +435,36 @@ class WikiaPage(object):
     '''
 
     if not getattr(self, '_images', False):
-      self._images = [
-        page['imageinfo'][0]['url']
-        for page in self.__continued_query({
-          'generator': 'images',
-          'gimlimit': 'max',
-          'prop': 'imageinfo',
-          'iiprop': 'url',
-        })
-        if 'imageinfo' in page
-      ]
+      query_params = {
+        'action': "Articles/AsSimpleJson?/",
+        'id': self.pageid,
+        'sub_wikia': self.sub_wikia,
+        'lang': LANG,
+      }
+      request = _wiki_request(query_params)
+      self._images = [section['images'][0]['src'] for section in request["sections"]
+                     if section['images']]
 
     return self._images
 
   @property
-  def coordinates(self):
+  def related_pages(self):
     '''
-    Tuple of Decimals in the form of (lat, lon) or None
+    Lists up to 10 of the wikia URLs of pages related to this page.
     '''
-    if not getattr(self, '_coordinates', False):
+    if not getattr(self, "_related_pages", False):
       query_params = {
-        'prop': 'coordinates',
-        'colimit': 'max',
-        'titles': self.title,
+        'action': "RelatedPages/List?/",
+        'ids': self.pageid,
+        'limit': 10,
+        'sub_wikia': self.sub_wikia,
+        'lang': LANG,
       }
-
       request = _wiki_request(query_params)
+      self._related_pages = [request['basepath'] + url['url']
+                            for url in request['items'][str(self.pageid)]]
 
-      if 'query' in request:
-        coordinates = request['query']['pages'][self.pageid]['coordinates']
-        self._coordinates = (Decimal(coordinates[0]['lat']), Decimal(coordinates[0]['lon']))
-      else:
-        self._coordinates = None
-
-    return self._coordinates
-
-  @property
-  def references(self):
-    '''
-    List of URLs of external links on a page.
-    May include external links within page that aren't technically cited anywhere.
-    '''
-
-    if not getattr(self, '_references', False):
-      def add_protocol(url):
-        return url if url.startswith('http') else 'http:' + url
-
-      self._references = [
-        add_protocol(link['*'])
-        for link in self.__continued_query({
-          'prop': 'extlinks',
-          'ellimit': 'max'
-        })
-      ]
-
-    return self._references
-
-  @property
-  def links(self):
-    '''
-    List of titles of Wikia page links on a page.
-
-    .. note:: Only includes articles from namespace 0, meaning no Category, User talk, or other meta-Wikia pages.
-    '''
-
-    if not getattr(self, '_links', False):
-      self._links = [
-        link['title']
-        for link in self.__continued_query({
-          'prop': 'links',
-          'plnamespace': 0,
-          'pllimit': 'max'
-        })
-      ]
-
-    return self._links
+    return self._related_pages
 
   @property
   def sections(self):
@@ -553,13 +474,14 @@ class WikiaPage(object):
 
     if not getattr(self, '_sections', False):
       query_params = {
-        'action': 'Search/List?/',
-        'prop': 'sections',
+        'action': 'Articles/AsSimpleJson?/',
+        'id': self.pageid,
+        'sub_wikia': self.sub_wikia,
+        'lang': LANG,
       }
-      query_params.update(self.__title_query_param)
 
       request = _wiki_request(query_params)
-      self._sections = [section['line'] for section in request['parse']['sections']]
+      self._sections = [section['title'] for section in request['sections']]
 
     return self._sections
 
@@ -574,20 +496,22 @@ class WikiaPage(object):
            the full text of all of the subsections. It only gets the text between
            `section_title` and the next subheading, which is often empty.
     '''
-
-    section = u"== {} ==".format(section_title)
-    try:
-      index = self.content.index(section) + len(section)
-    except ValueError:
+    if section_title not in self.sections:
       return None
 
-    try:
-      next_index = self.content.index("==", index)
-    except ValueError:
-      next_index = len(self.content)
-
-    return self.content[index:next_index].lstrip("=").strip()
+    query_params = {
+      'action': "Articles/AsSimpleJson?/",
+      'id': self.pageid,
+      'sub_wikia': self.sub_wikia,
+      'lang': LANG
+    }
 
+    request = _wiki_request(query_params)
+    section = "\n".join(segment['text'] for section in request['sections']
+                                        if section['title'] == section_title
+                                        for segment in section['content']
+                                        if segment['type'] == "paragraph")
+    return section
 
 @cache
 def languages():
@@ -612,16 +536,6 @@ def languages():
     for lang in languages
   }
 
-
-def donate():
-  '''
-  Open up the Wikimedia donate page in your favorite browser.
-  '''
-  import webbrowser
-
-  webbrowser.open('https://donate.wikimedia.org/w/index.php?title=Special:FundraiserLandingPage', new=2)
-
-
 def _wiki_request(params):
   '''
   Make a request to the Wikia API using the given search parameters.
@@ -629,8 +543,7 @@ def _wiki_request(params):
   '''
   global RATE_LIMIT_LAST_CALL
   global USER_AGENT
-  #params.update({"lang": LANG})
-  # Such as .../Search
+
   api_url = API_URL.format(**params)
   params['format'] = 'json'
   headers = {
@@ -651,7 +564,21 @@ def _wiki_request(params):
   if RATE_LIMIT:
     RATE_LIMIT_LAST_CALL = datetime.now()
 
-  return r.json()
+  # If getting the json representation did not work, our data is mangled
+  try:
+    r = r.json()
+  except ValueError:
+    raise WikiaError("Your request to the url \"{url}\" with the paramaters"
+                     "\"{params}\" returned data in a format other than JSON."
+                     "Please check your input data.").format(url=api_url,
+                                                             params=params)
+  # If we got a json response, then we know the format of the input was correct
+  if "exception" in r:
+    details, message, error_code= r['exception'].values()
+    if error_code == 408:
+      raise HTTPTimeoutError(query)
+    raise WikiaError("{}. {} ({})".format(message, details, error_code))
+  return r
 
 
 class WikiaError(Exception):
